(function($) {
	
	$.fn.spokenText = function(option) {
		return this.each(function(i) {
			var spokenText = new SpokenText(this, option);
			$(this).data("spokentext", spokenText);
		});
	}
	
	var SpokenText = function(container, option) {
		var defaultOption = {};
		
		this.container = container;
		this.newOption = $.extend({}, defaultOption, option || {});
		
		var content = $('<div class="spoken-text">' +
							'<div class="spoken-text-controller">' +
								'<input type="checkbox" id="textshower" />&nbsp;显示文本' +
							'</div>' +
							'<div class="spoken-text-container">' +
								'<textarea class="spoken-text-content" readonly="readonly"></textarea>' +
							'</div>' +
						'</div>');
		$(this.container).append(content);
		
		content.find("#textshower").change(function() {
			if ($(this).prop("checked")) {
				content.find(".spoken-text-container").show();
			} else {
				content.find(".spoken-text-container").hide();
			}
		});
		
		this.init = function(text) {
			content.find("#textshower").prop("checked", false);
			content.find(".spoken-text-container").hide();
			var t = (text == null || text == "") ? "当前无声音文本" : text;
			content.find(".spoken-text-content").html(t);
		}
		
	}
	
	$.fn.spoken = function(option) {
		return this.each(function(i) {
			var spoken = new Spoken(this, option);
			$(this).data("spoken", spoken);
		});
	}

	var Spoken = function(container, option) {
		var defaultOption = {};
		
		this.container = container;
		this.newOption = $.extend({}, defaultOption, option || {});
		
		this.examId;
		this.examName;
		this.examType;
		this.material;
		this.isAnswerCard;
		this.groups;
		this.events;
		this.rootPath;
		this.audioplayer;
		
		var content = $("<div class='spoken-exam'></div>");
		$(this.container).append(content);
		
		// 开始练习按钮添加事件
		content.on("click", ".spoken-exam-group-button", {that: this}, function(evt) {
			var instance = evt.data.that;
			if (instance.audioplayer == null || instance.events == null) {
				return;
			}
			var groupid = $(this).attr("id").split("_")[1];
			instance.audioplayer.seekByGroupId(groupid);
		});
		
		this.init = function(examData, examData2, eventData, player, isOnline, root) {
			if (isOnline) {
				this.rootPath = "http://exam2.kouyu100.com/";
			} else {
				this.rootPath = root;
			}
			this.audioplayer = player;
			this.parseExamXML(examData, examData2);
			this.parseEventXML(eventData);
			content.empty();
			this.drawGroup();
			
			/** 播放器播放进度监听 */
//			this.audioplayer.spokenCallback = this.onAudioProgress;
		}
		
		this.parseExamXML = function(data, data2) {
			this.examId = $(data).find("examId").text();
			this.examName = $(data).find("examName").text();
			this.examType = $(data).find("examType").text();
			this.material = $(data).find("material").text();
			this.isAnswerCard = $(data).find("isAnswerCard").text();
			this.groups = new Array();
			
			var grouplist = $(data).find("group");
			var grouplist2 = $(data2).find("group");
			for (var i = 0; i < grouplist.length; i++) {
				
				var g = grouplist[i];
				var g2 = grouplist2[i];
				
				var group = new SpokenGroup();
				group.id = $(g).children("id").text();
				group.groupType = $(g).children("groupType").text();
				group.groupName = $(g).children("groupName").text().replace(/###/g, "<br>");
				// 如果是图片 从exam.xml取数据 || 否则从exam2.xml中取数据
				var groupDesc = $(g).children("groupDesc").text();
				if (imageORtext(groupDesc) == "image") {
					group.groupDesc = $(g).children("groupDesc").text();
				} else {
					group.groupDesc = $(g2).children("groupDesc").text();
				}
				
				group.isReStart = $(g).children("isReStart").text();
				
				var choose_index = 0;
				
				var blanklist = $(g).find("blank");
				var blanklist2 = $(g2).find("blank");
				for (var j = 0; j < blanklist.length; j++) {
					
					var b = blanklist[j];
					var b2 = blanklist2[j];
					
					var blank = new SpokenBlank();
					blank.examId = this.examId;
					blank.groupId = group.id;
					blank.indexId = (++choose_index);
					blank.id = $(b).children("id").text();
					blank.title = $(b).children("title").text().replace(/###/g, "<br>");
					blank.answer = $(b2).children("answer").text();
					blank.score = $(b2).children("score").text();
					
					group.blanks.push(blank);
				}
				
				var chooselist = $(g).find("choose");
				var chooselist2 = $(g2).find("choose");
				for (var k = 0; k < chooselist.length; k++) {
					
					var c = chooselist[k];
					var c2 = chooselist2[k];
					
					var choose = new SpokenChoose();
					choose.examId = this.examId;
					choose.groupId = group.id;
					choose.indexId = (++choose_index);
					choose.id = $(c).children("id").text();
					choose.title = $(c).children("title").text().replace(/###/g, "<br>");
					choose.item1 = $(c).children("item1").text();
					choose.item2 = $(c).children("item2").text();
					choose.item3 = $(c).children("item3").text();
					choose.item4 = $(c).children("item4").text();
					choose.item5 = $(c).children("item5").text();
					choose.answer = $(c2).children("answer").text();
					choose.score = $(c2).children("score").text();
					
					choose.itemSize = 0;			
					if(choose.item1.length > 0){
						choose.itemSize++;
					}
					if(choose.item2.length > 0){
						choose.itemSize++;
					}
					if(choose.item3.length > 0){
						choose.itemSize++;
					}
					if(choose.item4.length > 0){
						choose.itemSize++;
					}
					if(choose.item5.length > 0){
						choose.itemSize++;
					}
					
					choose.itemType = imageORtext(choose.item1.toLowerCase());
					
					group.chooses.push(choose);
				}
				
				var repeatlist = $(g).find("repeat");
				for (var l = 0; l < repeatlist.length; l++) {
					var r = repeatlist[l];
					var repeat = new SpokenRepeat();
					repeat.examId = this.examId;
					repeat.groupId = group.id;
					repeat.indexId = (++choose_index);
					repeat.id = $(r).children("id").text();
					repeat.title = $(r).children("title").text().replace(/###/g, "<br>");
					
					group.repeats.push(repeat);
				}
				
				var questionlist = $(g).find("question");
				for (var m = 0; m < questionlist.length; m++) {
					var q = questionlist[m];
					var question = new SpokenQuestion();
					question.examId = this.examId;
					question.groupId = group.id;
					question.indexId = (++choose_index);
					question.id = $(q).children("id").text();
					question.title = $(q).children("title").text().replace(/###/g, "<br>");
					
					group.questions.push(question);
				}
				
				this.groups.push(group);
			}
		}
		
		this.parseEventXML = function(data) {
			this.events = new Array();
			
			var eventlist = $(data).find("time");
			
			for (var i = 0; i < eventlist.length; i++) {
				var e = eventlist[i];
				var evt = new SpokenEvent();
				evt.groupid = $(e).children("groupid").text();
				evt.titleid = $(e).children("titleid").text();
				evt.titletype = $(e).children("titletype").text();
				evt.start = $(e).children("start").text();
				evt.end = $(e).children("end").text();
				evt.eventtype = $(e).children("eventtype").text();
				evt.extend = $(e).children("extend").text();
				
				this.events.push(evt);
			}
		}
		
		this.drawGroup = function() {
			
			var examTitle = "<h2 class='spoken-exam-title'>" + this.examName + "</h2>";
			content.append(examTitle);
			
			for (var i = 0; i < this.groups.length; i++) {
				var group = this.groups[i];
				var groupDiv = "<div class='spoken-exam-group' id='spokenGroup_" + group.id + "'>" + group.groupName + "</div>";
				content.append(groupDiv);
				var groupButton = "<div class='spoken-exam-group-button' id='spokenGroupButton_" + group.id + "'>开始练习</div>";
				$("#spokenGroup_" + group.id).append(groupButton);
				
				// group.groupDesc 分情况判断显示
				var descType = imageORtext(group.groupDesc.toLowerCase());
				if (descType == "image") {
					var descImage = "<div class='group-desc-image'><img src='" + this.rootPath + group.groupDesc + "' style='max-width:90%'/></div>";
					$("#spokenGroup_" + group.id).append(descImage);
				} else if (descType == "text" && group.groupDesc.indexOf("#td#") != -1) {
					var table_str = "";
					var rows = group.groupDesc.split("#br#");
					for (var ii = 0; ii < rows.length; ii++) {
						table_str += "<tr>";
						if (rows[ii].indexOf("#td#") != -1) {
							rows[ii] = rows[ii].split("#td#");
						} else {
							rows[ii] = [rows[ii]];
						}
						for (var j = 0; j < rows[ii].length; j++) {
							table_str += "<td";
							if (rows[ii].length == 1) {
								table_str += " colspan='2' align='center'";
							}
							table_str += (">" + rows[ii][j] + "</td>");
						}
						table_str += "</tr>";
					}
					var descTable = "<table class='group-desc-table'>" + table_str + "</table>";
					$("#spokenGroup_" + group.id).append(descTable);
				} else if (descType == "text" && group.groupDesc.length > 0) {
					var descText = "<div class='group-desc-text'>" + group.groupDesc + "</div>";
					$("#spokenGroup_" + group.id).append(descText);
				}
				
				for (var j = 0; j < group.blanks.length; j++) {
					var blank = group.blanks[j];
					this.drawBlank(blank);
				}
				
				for(var k = 0; k < group.chooses.length; k++){
					var choose = group.chooses[k];
					this.drawChoose(choose);
				}
				
				for (var l = 0; l < group.repeats.length; l++) {
					var repeat = group.repeats[l];
					this.drawRepeat(repeat);
				}
				
				for (var m = 0; m < group.questions.length; m++) {
					var question = group.questions[m];
					this.drawQuestion(question);
				}
			}
		}
		
		this.drawBlank = function(blank) {
			var blankDiv = "<div class='spoken-exam-blank' id='spokenBlank_" + blank.id + "'><span>" + blank.title + "</span><input type='text' score='" + blank.score + "' answer='" + blank.answer + "' /><span class='spoken-exam-blank-answer'>&nbsp;答案：" + blank.answer + "</span></div>";
			$("#spokenGroup_" + blank.groupId).append(blankDiv);
		}
		
		this.drawChoose = function(choose) {
			if (choose.itemType == "image") {
				this.drawChooseImage(choose);
			} else {
				this.drawChooseText(choose);
			}
		}
		
		this.drawChooseImage = function(choose) {
			var chooseDiv = "<div class='spoken-exam-choose' id='spokenChoose_"+choose.id+"'><div>" + choose.indexId + "." + choose.title + "</div></div>";
			$("#spokenGroup_" + choose.groupId).append(chooseDiv);
			
			var choose_str = "<div class='spoken-exam-choose-option'>";
			if(choose.itemSize>0){
				choose_str += "<span class='spoken-exam-choose-option-image'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='A' answer='" + choose.answer + "' score='" + choose.score + "'>A.<img src='" + this.rootPath + choose.item1 + "' width='100px'/></span>";
			}	
			if(choose.itemSize>1){
				choose_str += "<span class='spoken-exam-choose-option-image'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='B' answer='" + choose.answer + "' score='" + choose.score + "'>B.<img src='" + this.rootPath + choose.item2 + "' width='100px'/></span>";
			}	
			if(choose.itemSize>2){
				choose_str += "<span class='spoken-exam-choose-option-image'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='C' answer='" + choose.answer + "' score='" + choose.score + "'>C.<img src='" + this.rootPath + choose.item3 + "' width='100px'/></span>";
			}	
			if(choose.itemSize>3){
				choose_str += "<span class='spoken-exam-choose-option-image'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='D' answer='" + choose.answer + "' score='" + choose.score + "'>D.<img src='" + this.rootPath + choose.item4 + "' width='100px'/></span>";
			}	
			if(choose.itemSize>4){
				choose_str += "<span class='spoken-exam-choose-option-image'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='E' answer='" + choose.answer + "' score='" + choose.score + "'>E.<img src='" + this.rootPath + choose.item5 + "' width='100px'/></span>";
			}	
	
			choose_str += "</div>";
			$("#spokenChoose_"+choose.id).append(choose_str);
		}
		
		this.drawChooseText = function(choose) {
			var chooseDiv = "<div class='spoken-exam-choose' id='spokenChoose_"+choose.id+"'><div>" + choose.indexId + "." + choose.title + "</div></div>";
			$("#spokenGroup_" + choose.groupId).append(chooseDiv);
			
			var choose_str = "<div class='spoken-exam-choose-option'>";
			if(choose.itemSize > 0){
				choose_str += "<div class='spoken-exam-choose-option-text'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='A' answer='" + choose.answer + "' score='" + choose.score + "'>A."+choose.item1+"</div>";
			}	
			if(choose.itemSize > 1){
				choose_str += "<div class='spoken-exam-choose-option-text'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='B' answer='" + choose.answer + "' score='" + choose.score + "'>B."+choose.item2+"</div>";
			}	
			if(choose.itemSize>2){
				choose_str += "<div class='spoken-exam-choose-option-text'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='C' answer='" + choose.answer + "' score='" + choose.score + "'>C."+choose.item3+"</div>";
			}	
			if(choose.itemSize>3){
				choose_str += "<div class='spoken-exam-choose-option-text'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='D' answer='" + choose.answer + "' score='" + choose.score + "'>D."+choose.item4+"</div>";
			}	
			if(choose.itemSize>4){
				choose_str += "<div class='spoken-exam-choose-option-text'><input type='radio' name='spokenChooseAnswer_" + choose.id + "' alt='E' answer='" + choose.answer + "' score='" + choose.score + "'>E."+choose.item5+"</div>";
			}
			choose_str += "</div>";
			$("#spokenChoose_"+choose.id).append(choose_str);
		}
		
		this.drawRepeat = function(repeat) {
			var repeatDiv = "<div class='spoken-exam-repeat' id='spokenRepeat_" + repeat.id + "'><span>" + repeat.title + "</span></div>";
			$("#spokenGroup_" + repeat.groupId).append(repeatDiv);
		}
		
		this.drawQuestion = function(question) {
			var questionDiv = "<div class='spoken-exam-question' id='spokenQuestion_" + question.id + "'><span>" + question.title + "</span></div>";
			$("#spokenGroup_" + question.groupId).append(questionDiv);
		}
		
		this.showAnswer = function(json) {
			var answers = JSON.parse(json);
			var score = 0;
			for (var i = 0; i < answers.length; i++) {
				var answer = answers[i];
				var answerDiv = "<div class='spoken-exam-answer' id='apokenAnswer_'" + answer.titleId + ">参考答案：" + answer.content1 + "</div>";
				var ids = "#spokenBlank_" + answer.titleId + ",#spokenChoose_" + answer.titleId + ",#spokenRepeat_" + answer.titleId + ",#spokenQuestion_" + answer.titleId;
				$("#spokenGroup_" + answer.groupId).find(ids).after(answerDiv);
			}
			
			content.find("input").each(function(i, e) {
				if ($(e).attr("type") == "text") {
					$(e).attr("readonly", "readonly");
					if ($(e).val().toLowerCase() == $(e).attr("answer").toLowerCase()) {
						score += parseInt($(e).attr("score"));
//						$(e).siblings(".spoken-exam-blank-answer").html("<img src='../../images/classroom/dui.png' />").show();
						$(e).siblings(".spoken-exam-blank-answer").html("<img src='chrome://teacher_tools/content/images/classroom/dui.png' />").show();
					} else {
						$(e).siblings(".spoken-exam-blank-answer").show();
					}
				} else if ($(e).attr("type") == "radio") {
					$(e).attr("disabled", "disabled");
					
					if ($(e).prop("checked") == true) {
						if ($(e).attr("alt").toLowerCase() == $(e).attr("answer").toLowerCase()) {
							score += parseInt($(e).attr("score"));
//							$(e).parent().append("<img src='../../images/classroom/dui.png' />");
							$(e).parent().append("<img src='chrome://teacher_tools/content/images/classroom/dui.png' />");
						} else {
//							$(e).parent().append("<img src='../../images/classroom/ch.png' />");
							$(e).parent().append("<img src='chrome://teacher_tools/content/images/classroom/ch.png' />");
						}
					}
					if ($(e).attr("alt").toLowerCase() == $(e).attr("answer").toLowerCase()) {
						$(e).parent().css("color", "red");
						$(e).prop("checked", true);
					}
				}
			});
			return score;
		}
		
		// 监听播放器的播放进度事件
		this.onAudioProgress = function(time) {
			var currentGroupId;
			for (var i = 0; i < this.events.length; i++) {
				var e = this.events[i];
				if (e.eventtype == "2" && time >= e.start) {
					currentGroupId = e.groupid;
				}
			}
			if (currentGroupId == null) {
				return;
			}
			$(".spoken-exam-group").hide();
			$("#spokenGroup_" + currentGroupId).show();
		}
		
		
	}




	var SpokenGroup = function() {
		this.id;
		this.groupType;
		this.groupName;
		this.groupDesc;
		this.isReStart;	
		this.examId;	
		this.chooses = new Array();	
		this.blanks = new Array();
		this.repeats = new Array();
		this.questions = new Array();
	}
	
	var SpokenChoose = function() {
		this.id;
		this.title;
		this.itemType;
		this.itemSize;
		this.item1;
		this.item2;
		this.item3;
		this.item4;
		this.item5;
		this.indexId;
		this.examId;
		this.groupId;
		this.chooseId;
		this.answer;
		this.score;
	}
	
	var SpokenBlank = function() {
		this.id;
		this.title;
		this.indexId;
		this.examId;
		this.groupId;
		this.answer;
		this.score;
	}
	
	var SpokenRepeat = function() {
		this.id;
		this.title;
		this.indexId;
		this.examId;
		this.groupId;
		this.answer;
		this.score;
	}
	
	var SpokenQuestion = function() {
		this.id;
		this.title;
		this.indexId;
		this.examId;
		this.groupId;
		this.answer;
		this.score;
	}
	
	var SpokenEvent = function() {
		this.groupid;
		this.titleid;
		this.titletype;
		this.start;
		this.end;
		this.eventtype;
		this.extend;
	}

	function imageORtext(name) {
		var extenname = name.substr(name.length - 4, 4);
		if (extenname == ".jpg" || extenname == ".png" || extenname == ".gif") {
			return "image";
		} else {
			return "text";
		}
	}

})(jQuery);